﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace Web_EditModeAndLegendLayer
{
    public partial class Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapUnit = GeographyUnit.DecimalDegree;
                WorldMapKitWmsWebOverlay worldMapKitWmsWebOverlay = new WorldMapKitWmsWebOverlay("WorldMapKitOverlay");
                Map1.CustomOverlays.Add(worldMapKitWmsWebOverlay);

                //BuildLeagend();

                Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
            }
        }

        protected void buttonDrawPoint_Click(object sender, EventArgs e)
        {
            // Add leagend into map.
            BuildLeagend();
            // Set TrackMode for edit shapes.
            Map1.EditOverlay.TrackMode = TrackMode.Point;
        }

        protected void Map1_TrackShapeFinished(object sender, EventArgs e)
        {

            var features = Map1.EditOverlay.Features;
            int pointFeatureCount = 0;
            foreach (Feature feature in features)
            {
                var featureType = feature.GetWellKnownType();
                // Get the type of the shape we edited, update the correspond number in the legend. 
                if (featureType == WellKnownType.Point)
                {
                    pointFeatureCount++;
                }
            }

            LegendAdornmentLayer legendLayer = (LegendAdornmentLayer)Map1.AdornmentOverlay.Layers["legend"];

            LegendItem legendItemPoint = legendLayer.LegendItems["Point"];
            legendItemPoint.TextStyle = new TextStyle(string.Format("Point feature number  {0}", pointFeatureCount.ToString()), new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));

        }

        private void BuildLeagend()
        {
            if (Map1.AdornmentOverlay.Layers.Contains("legend"))
            {
                return;
            }
            LegendAdornmentLayer legendLayer = new LegendAdornmentLayer();
            legendLayer.BackgroundMask = AreaStyles.CreateLinearGradientStyle(new GeoColor(255, 255, 255, 255), new GeoColor(255, 230, 230, 230), 90, GeoColor.SimpleColors.Black);
            legendLayer.Height = 100;
            legendLayer.Width = 175;
            legendLayer.Location = AdornmentLocation.LowerLeft;
            legendLayer.XOffsetInPixel = 10;
            LegendItem title = new LegendItem();
            title.TextStyle = new TextStyle("SCOREBOARD", new GeoFont("Arial", 10, DrawingFontStyles.Bold), new GeoSolidBrush(GeoColor.SimpleColors.Black));
            legendLayer.Title = title;

            LegendItem legendItemPoint = new LegendItem();
            legendItemPoint.ImageStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColors.ForestGreen, 12);
            legendItemPoint.TextStyle = new TextStyle("Point feature number  0", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.Black));
            legendLayer.LegendItems.Add("Point", legendItemPoint);


            Map1.AdornmentOverlay.Layers.Add("legend", legendLayer);
        }

    }
}